#!/usr/bin/env python2
# vim: set fileencoding=utf-8:
# @Author: Vayn a.k.a. VT <vayn@vayn.de>
# @Name: config.py
# @Date: 2011年06月11日 星期六 10时28分16秒

'''
  vinergy.config
  ~~~~~~~~~~~~~~

  Vinergy configuration
'''


### Site url
URL = 'http://localhost:8080'


### Database url
DBURL = {'host': 'localhost',
         'port': 27017,
        }

### Url length
PAD = 3
